==> jaxrs-ri-2.3.1-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/internal/monitoring/jmx/ResourcesMBeanGroup.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.server.internal.monitoring.jmx;

import java.util.Map;

import org.glassfish.jersey.server.monitoring.ResourceStatistics;

import com.google.common.collect.Maps;

/**
 * Group of resource MXBeans.
 *
 * @author Miroslav Fuksa (miroslav.fuksa at oracle.com)
 */
public class ResourcesMBeanGroup {
    private final Map<String, ResourceMxBeanImpl> exposedResourceMBeans = Maps.newHashMap();
    private final String parentName;
    private final boolean uriResource;
    private final MBeanExposer exposer;

    /**
     * Create a new group of MXBeans and expose nested Resource MXBeans.
     * @param resourceStatistics Resource statistics that should be exposed by nested MXBeans.
     * @param uriResource {@code true} if the resources are identified by URI (and not by java class names for example).
     * @param mBeanExposer mbean exposer.
     * @param parentName Name of the parent bean.
     */
    public ResourcesMBeanGroup(Map<String, ResourceStatistics> resourceStatistics,
                               boolean uriResource,
                               MBeanExposer mBeanExposer,
                               String parentName) {
        this.uriResource = uriResource;
        this.exposer = mBeanExposer;
        this.parentName = parentName;

        updateResourcesStatistics(resourceStatistics);
    }

    /**
     * Update the resource statistics exposed by nested resource beans.
     *
     * @param resourceStatistics New resource statistics.
     */
    public void updateResourcesStatistics(Map<String, ResourceStatistics> resourceStatistics) {
        for (Map.Entry<String, ResourceStatistics> entry : resourceStatistics.entrySet()) {
            ResourceMxBeanImpl resourceMxBean = exposedResourceMBeans.get(entry.getKey());
            if (resourceMxBean == null) {
                resourceMxBean = new ResourceMxBeanImpl(entry.getValue(), entry.getKey(), uriResource, exposer, parentName);
                exposedResourceMBeans.put(entry.getKey(), resourceMxBean);
            }
            resourceMxBean.updateResourceStatistics(entry.getValue());
        }
    }
}

==> jaxrs-ri-2.10.1-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/internal/monitoring/jmx/ResourcesMBeanGroup.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.server.internal.monitoring.jmx;

import java.util.Map;

import org.glassfish.jersey.server.monitoring.ResourceStatistics;

import jersey.repackaged.com.google.common.collect.Maps;

/**
 * Group of resource MXBeans.
 *
 * @author Miroslav Fuksa (miroslav.fuksa at oracle.com)
 */
public class ResourcesMBeanGroup {
    private final Map<String, ResourceMxBeanImpl> exposedResourceMBeans = Maps.newHashMap();
    private final String parentName;
    private final boolean uriResource;
    private final MBeanExposer exposer;

    /**
     * Create a new group of MXBeans and expose nested Resource MXBeans.
     * @param resourceStatistics Resource statistics that should be exposed by nested MXBeans.
     * @param uriResource {@code true} if the resources are identified by URI (and not by java class names for example).
     * @param mBeanExposer mbean exposer.
     * @param parentName Name of the parent bean.
     */
    public ResourcesMBeanGroup(Map<String, ResourceStatistics> resourceStatistics,
                               boolean uriResource,
                               MBeanExposer mBeanExposer,
                               String parentName) {
        this.uriResource = uriResource;
        this.exposer = mBeanExposer;
        this.parentName = parentName;

        updateResourcesStatistics(resourceStatistics);
    }

    /**
     * Update the resource statistics exposed by nested resource beans.
     *
     * @param resourceStatistics New resource statistics.
     */
    public void updateResourcesStatistics(Map<String, ResourceStatistics> resourceStatistics) {
        for (Map.Entry<String, ResourceStatistics> entry : resourceStatistics.entrySet()) {
            ResourceMxBeanImpl resourceMxBean = exposedResourceMBeans.get(entry.getKey());
            if (resourceMxBean == null) {
                resourceMxBean = new ResourceMxBeanImpl(entry.getValue(), entry.getKey(), uriResource, exposer, parentName);
                exposedResourceMBeans.put(entry.getKey(), resourceMxBean);
            }
            resourceMxBean.updateResourceStatistics(entry.getValue());
        }
    }
}
